package org.tranql.connector.informix;


import org.tranql.connector.NoExceptionsAreFatalSorter;
import org.tranql.connector.jdbc.AbstractXADataSourceMCF;
import com.informix.jdbcx.IfxXADataSource;


public class XAMCF extends AbstractXADataSourceMCF {
    
	private final IfxXADataSource ds;
    private String password = "";

    /**
     * Default constructor for an Informix XA DataSource.
     */
    public XAMCF() {
        super(new IfxXADataSource(), new NoExceptionsAreFatalSorter());
        ds = (IfxXADataSource) xaDataSource;
    }
 
    public void setServerName(String sn) {
        ds.setServerName(sn);
    }

    public String getServerName() {
        return ds.getServerName();
    }
    
    public void setDatabaseName(String dbname) {
        ds.setDatabaseName(dbname);
    }

    public String getDatabaseName() {
        return ds.getDatabaseName();
    }

    public void setUserName(String user) {
        ds.setUser(user);
    }

    public String getUserName() {
        return ds.getUser();
    }
    
    public void setPassword(String pwd) {
        this.password = pwd;
        ds.setPassword(pwd);
    }

    public String getPassword() {
        return password;
    }

    public void setPortNumber(Integer pn) {
        ds.setPortNumber(pn == null ? 0 : pn.intValue());
    }

    public Integer getPortNumber() {
        return new Integer(ds.getPortNumber());
    }
    
    //The following are Informix specific values.
    
    public void setIfxHost(String ifxHost){
    	if (ifxHost == null || ifxHost.trim().length() == 0) {
            return;
        }
    	ds.setIfxIFXHOST(ifxHost);    	
    }
    
    public String getIfxHost(){
    	return ds.getIfxIFXHOST();
    }
    
    public void setIfxProtocolTrace(Integer ifxPT) {
        ds.setIfxPROTOCOLTRACE(ifxPT == null ? 0 : ifxPT.intValue());
    }

    public Integer getIfxProtocolTrace() {
        return new Integer(ds.getIfxPROTOCOLTRACE());
    }
    
    public void setIfxProtocolTraceFile(String ifxPTF) {
        if (ifxPTF == null || ifxPTF.trim().length() == 0) {
            return;
        }
        ds.setIfxPROTOCOLTRACEFILE(ifxPTF);
    }
   
    public String getIfxProtocolTraceFile() {
        return ds.getIfxPROTOCOLTRACEFILE();
    }
    
    public void setIfxSQLHostFile(String ifxSF) {
        if (ifxSF == null || ifxSF.trim().length() == 0) {
            return;
        }
        ds.setIfxSQLH_FILE(ifxSF);
    }
   
    public String getIfxSQLHostFile() {
        return ds.getIfxSQLH_FILE();
    }
    
    public void setIfxSQLHostType(String ifxST) {
    	if (ifxST == null || ifxST.trim().length() == 0) {
            return;
        }
        ds.setIfxSQLH_TYPE(ifxST);
    }
    
    public String getIfxSQLHostType() {
        return ds.getIfxSQLH_TYPE();
    }
    
    /**
     * Equality is defined in terms of the serverName, portNumber and databaseName properties
     */
    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj instanceof XAMCF) {
        	IfxXADataSource other = ((XAMCF) obj).ds;
            return equals(ds.getServerName(), other.getServerName()) &&
                    ds.getPortNumber() == other.getPortNumber() &&
                    equals(ds.getDatabaseName(), other.getDatabaseName());
        } else {
            return false;
        }
    }

    private static boolean equals(String a, String b) {
        return a == b || a != null && a.equals(b);
    }

    public int hashCode() {
        return hashCode(ds.getServerName()) ^ ds.getPortNumber() ^ hashCode(ds.getDatabaseName());
    }

    private static int hashCode(String s) {
        return s == null ? 0 : s.hashCode();
    }

    public String toString() {
        return "XAMCF[" + getDatabaseName() + ']';
    }
}
